@@ -13,7 +13,7 @@
 #' about controlled companies
 #' @param periodicy.fin.report The frequency of financial reports: 'annual' (default) or 'quarterly'
 #' @param inflation.index Sets the inflation index to use for finding inflation adjusted values of all reports. Possible values: 'dollar' (default) or 'IPCA', the brazilian main inflation index.
-#' When using 'IPCA', the base date is set as the last date found in the inflation dataset.
+#' When using 'IPCA', the base date is set as the last date found in itr/dfp dataset.
 #' @param max.levels Sets the maximum number of levels of accounting items in financial reports
 #' @param folder.out Folder where to download and manipulate the zip files. Default = tempdir()
 #' @param be.quiet Should the function output information about progress? TRUE (default) or FALSE
@@ -82,7 +82,7 @@ gitrd.GetITRData <- function(name.companies,
   }
 
   # get data from github
-  df.info <- gitrd.get.info.companies()
+  df.info <- gitrd.get.info.companies(type.data = 'companies_files')
   unique.names <- unique(df.info$name.company)
 
   idx <- !(name.companies %in% unique.names)
@@ -110,7 +110,7 @@ gitrd.GetITRData <- function(name.companies,
   df.to.process <- df.info[idx, ]
 
   # remove duplicates/NA and filter for type.data
-  idx <- !duplicated(df.to.process[, c('id.company', 'id.date')])
+  idx <- !duplicated(df.to.process[, c('id.company', 'id.date', 'type.fin.report')])
   df.to.process <- df.to.process[idx, ]
 
   idx <- !is.na(df.to.process$id.company)
@@ -119,10 +119,6 @@ gitrd.GetITRData <- function(name.companies,
   idx <- !is.na(df.to.process$name.company)
   df.to.process <- df.to.process[idx, ]
 
-  idx <- df.to.process$type.fin.report == type.fin.report
-  df.to.process <- df.to.process[idx, ]
-
-
   if (nrow(df.to.process) == 0){
     stop('Cannot find any dates related to companies in registry. You should try different dates and companies.')
   }
@@ -137,23 +133,18 @@ gitrd.GetITRData <- function(name.companies,
   }
 
   cat(paste0('\n\nDownloading data for ', length(name.companies), ' companies',
-             '\nReach of financial reports: ', msg.reach,
+             '\nType of financial reports: ', msg.reach,
              '\nPeriodicy of financial reports: ', periodicy.fin.report, ' (',type.fin.report, ' system)',
              '\nFirst Date: ',first.date,
              '\nLaste Date: ',last.date,
              '\nInflation index: ', inflation.index,
              '\n\n') )
 
-  cat(paste0('Downloading ', inflation.index, ' data using BETS'))
+  cat(paste0('Downloading inflation data' ))
 
   # download inflation data using BETS
-  id.inflation <- switch(inflation.index,
-                         'IPCA' = '433',
-                         'dollar' = '1')
 
-  df.inflation <- BETS::BETS.get(code = id.inflation,
-                                 from = as.character(first.date),
-                                 to = as.character(last.date), data.frame = T )
+  df.inflation <- gitrd.get.inflation.data(inflation.index)
 
   cat('\tDone\n\n')
 
@@ -170,10 +161,12 @@ gitrd.GetITRData <- function(name.companies,
   }
 
   # start processing
-  cat(paste0('Inputs looks good! Downloading data:' ) )
+  cat(paste0('Inputs looking good! Starting download of files:\n' ) )
 
   for (i.company in unique(df.to.process$name.company) ) {
-    temp.df <- df.to.process[df.to.process$name.company == i.company, ]
+    idx <- (df.to.process$name.company == i.company)&
+      (df.to.process$type.fin.report == type.fin.report)
+    temp.df <- df.to.process[idx, ]
     cat(paste0('\n', i.company) )
 
     cat(paste0('\n\tAvailable periods: ', paste0(temp.df$id.date, collapse = '\t')) )
@@ -186,15 +179,17 @@ gitrd.GetITRData <- function(name.companies,
 
   for (i.company in unique(df.to.process$name.company)) {
 
-    temp.df <- df.to.process[df.to.process$name.company == i.company,  ]
+    idx <- (df.to.process$name.company == i.company)&
+      (df.to.process$type.fin.report == type.fin.report)
+    temp.df <- df.to.process[idx,  ]
 
     # get data from Bovespa site
     my.id <- temp.df$id.company[1]
 
     l.out.bov <- gitrd.get.bovespa.data(my.id)
 
-    df.stock.holders <- l.out.bov$df.stock.holders
-    df.stock.composition <- l.out.bov$df.stock.composition
+    current.stock.holders <- l.out.bov$df.stock.holders
+    current.stock.composition <- l.out.bov$df.stock.composition
     df.dividends <- l.out.bov$df.dividends
 
     type.info.now <- type.info[which(i.company == name.companies)]
@@ -202,6 +197,8 @@ gitrd.GetITRData <- function(name.companies,
     df.liabilities <- data.frame()
     df.income <- data.frame()
     df.cashflow <- data.frame()
+    df.fre.stock.holders <- data.frame()
+    df.fre.capital <- data.frame()
     for (i.date in as.character(temp.df$id.date) ) {
 
       temp.df2 <- temp.df[temp.df$id.date == i.date,  ]
@@ -217,6 +214,7 @@ gitrd.GetITRData <- function(name.companies,
       }
 
 
+      # get dfp/itr data
       dl.link <- temp.df2$dl.link
       type.fin.report <- temp.df2$type.fin.report
 
@@ -229,10 +227,12 @@ gitrd.GetITRData <- function(name.companies,
                                                i.date, '.zip') )
 
 
+      cat(paste0('\n\tAcessing ', type.fin.report, ' data') )
+
       if (file.exists(temp.file)) {
-        cat('\tfile exists (no dl)')
+        cat(' | file exists (no dl)')
       } else {
-        cat('\tDownloading')
+        cat(' | downloading file')
 
         utils::download.file(url = dl.link,
                              destfile = temp.file,
@@ -240,7 +240,7 @@ gitrd.GetITRData <- function(name.companies,
                              mode = 'wb')
       }
 
-      cat(' | Reading file')
+      cat(' | reading file')
 
       suppressWarnings({
         l.out <- gitrd.read.zip.file(my.zip.file = temp.file, folder.to.unzip = tempdir(),
@@ -255,6 +255,7 @@ gitrd.GetITRData <- function(name.companies,
         out.df <- l.out$cons.dfs
       }
 
+
       # set some cols for long format
       out.df$df.assets$ref.date <- as.Date(i.date)
       out.df$df.assets$company.name <- i.company
@@ -270,6 +271,66 @@ gitrd.GetITRData <- function(name.companies,
       df.income <- rbind(df.income, out.df$df.income)
       df.cashflow <- rbind(df.cashflow, out.df$df.cashflow)
 
+      # get data from FRE
+
+      cat(paste0('\n\tAcessing fre data') )
+
+      idx <- (df.to.process$name.company == i.company)&
+        (df.to.process$type.fin.report == 'fre')&
+        (df.to.process$id.date == temp.df2$id.date)
+
+      temp.df.fre <- df.to.process[idx,  ]
+
+      if (nrow(temp.df.fre) == 0) {
+        cat('\n\t\tNo FRE file available..')
+
+        next()
+
+      }
+
+      temp.file = file.path(folder.out, paste0('FRE_', temp.df2$id.company, '_',
+                                               stringr::str_sub(my.filename,1,4), '_',
+                                               i.date, '.zip') )
+
+
+      dl.link <- temp.df.fre$dl.link
+
+      if (file.exists(temp.file)) {
+        cat(' | file exists (no dl)')
+      } else {
+        cat(' | downloading file')
+
+        utils::download.file(url = dl.link,
+                             destfile = temp.file,
+                             quiet = T,
+                             mode = 'wb')
+      }
+
+      cat(' | reading file')
+
+      l.out.FRE <- gitrd.read.fre.zip.file(my.zip.file = temp.file,
+                                           folder.to.unzip = tempdir(),
+                                           l.other.info = list(company.name = temp.df2$name.company,
+                                                               ref.date = temp.df2$id.date))
+
+      # set new cols and fix order
+      old.names <- names(l.out.FRE$df.stockholders)
+      l.out.FRE$df.stockholders$name.company <- temp.df2$name.company
+      l.out.FRE$df.stockholders$id.date <- temp.df2$id.date
+
+      my.cols <- c('name.company', 'id.date', old.names)
+      l.out.FRE$df.stockholders <- l.out.FRE$df.stockholders[ ,my.cols]
+
+      # set new cols and fix order
+      old.names <- names(l.out.FRE$df.capital)
+      l.out.FRE$df.capital$name.company <- temp.df2$name.company
+      l.out.FRE$df.capital$id.date <- temp.df2$id.date
+
+      my.cols <- c('name.company', 'id.date', old.names)
+      l.out.FRE$df.capital <- l.out.FRE$df.capital[ ,my.cols]
+
+      df.fre.stock.holders <- rbind(df.fre.stock.holders, l.out.FRE$df.stockholders)
+      df.fre.capital <- rbind(df.fre.capital, l.out.FRE$df.capital)
     }
 
     # clean up dataframes before saving
@@ -284,13 +345,14 @@ gitrd.GetITRData <- function(name.companies,
                                      min.date = min(temp.df$id.date),
                                      max.date = max(temp.df$id.date),
                                      n.periods = length(temp.df$id.date),
-                                     stock.holders = list(df.stock.holders),
-                                     stock.composition = list(df.stock.composition),
+                                     current.stock.composition = list(current.stock.composition),
                                      dividends.history = list(df.dividends),
                                      fr.assets = list(df.assets),
                                      fr.liabilities = list(df.liabilities),
                                      fr.income = list(df.income),
-                                     fr.cashflow = list(df.cashflow))
+                                     fr.cashflow = list(df.cashflow),
+                                     history.stock.holders = list(df.fre.stock.holders),
+                                     history.capital = list(df.fre.capital) )
 
     tibble.out <- dplyr::bind_rows(tibble.out, tibble.company)
 
